Struct Adapter
struct Adapter { ... }
An adapter between a Unicode back end an the idna crate.
Implementations
impl Adapter
const fn new() -> SelfConstructor using data compiled into the binary.
fn is_virama(self: &Self, c: char) -> booltrueiff the Canonical_Combining_Class ofcis Virama.fn is_mark(self: &Self, c: char) -> booltrueiff the General_Category ofcis Mark, i.e. any of Nonspacing_Mark, Spacing_Mark, or Enclosing_Mark.fn bidi_class(self: &Self, c: char) -> BidiClassReturns the Bidi_Class of
c.fn joining_type(self: &Self, c: char) -> JoiningTypeReturns the Joining_Type of
c.fn map_normalize<'delegate, I: Iterator<Item = char> + 'delegate>(self: &'delegate Self, iter: I) -> impl Iterator<Item = char> + 'delegateSee the method of the same name in
icu_normalizerfor the exact semantics.fn normalize_validate<'delegate, I: Iterator<Item = char> + 'delegate>(self: &'delegate Self, iter: I) -> impl Iterator<Item = char> + 'delegateSee the method of the same name in
icu_normalizerfor the exact semantics.
impl Default for Adapter
fn default() -> Self
impl Freeze for Adapter
impl RefUnwindSafe for Adapter
impl Send for Adapter
impl Sync for Adapter
impl Unpin for Adapter
impl UnsafeUnpin for Adapter
impl UnwindSafe for Adapter
impl<T> Any for Adapter
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Adapter
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Adapter
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> ErasedDestructor for Adapter
impl<T> From for Adapter
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Adapter
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Adapter
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Adapter
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>